"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const schematics_1 = require("@angular-devkit/schematics");
const core_1 = require("@angular-devkit/core");
const schematics_utilities_1 = require("schematics-utilities");
const angular_schematic_utils_1 = require("@objectivity/angular-schematic-utils");
function tsImportPath(options) {
    return (_tree, _context) => {
        return schematics_1.chain([
            updateTsConfig(options)
        ]);
    };
}
exports.tsImportPath = tsImportPath;
function updateTsConfig(options) {
    return (tree, _context) => {
        const workspace = schematics_utilities_1.getWorkspace(tree);
        const projectName = options.project;
        const workspaceProject = schematics_utilities_1.getProjectFromWorkspace(workspace, projectName);
        const projectPath = angular_schematic_utils_1.trimSlashes(schematics_utilities_1.buildDefaultPath(workspaceProject));
        const projectEnvPath = angular_schematic_utils_1.trimSlashes(angular_schematic_utils_1.getProjectEnvironmentPath(workspaceProject));
        const projectKey = `@${projectName}/*`;
        const projectEnvKey = `@${projectName}-env/*`;
        const pathToProject = {
            [projectKey]: [`${projectPath}/*`],
            [projectEnvKey]: [`${projectEnvPath}/*`],
        };
        const tsConfigPath = 'tsconfig.json';
        try {
            const tsCfgJsonContent = tree.read(tsConfigPath);
            if (!tsCfgJsonContent) {
                throw new Error('Invalid path: ' + tsConfigPath);
            }
            const tsCfgAst = core_1.parseJsonAst(tsCfgJsonContent.toString('utf-8'));
            if (tsCfgAst.kind !== 'object') {
                throw new Error('Invalid tsconfig content.');
            }
            const compilerOptionsAstNode = schematics_utilities_1.findPropertyInAstObject(tsCfgAst, 'compilerOptions');
            if (!compilerOptionsAstNode || compilerOptionsAstNode.kind !== 'object') {
                throw new Error('Invalid compilerOptions content.');
            }
            const pathsAstNode = schematics_utilities_1.findPropertyInAstObject(compilerOptionsAstNode, 'paths');
            const recorder = tree.beginUpdate(tsConfigPath);
            if (!pathsAstNode) {
                schematics_utilities_1.appendPropertyInAstObject(recorder, compilerOptionsAstNode, "paths", pathToProject, 4);
            }
            else {
                if (pathsAstNode.kind !== 'object') {
                    throw new Error('Invalid paths content.');
                }
                schematics_utilities_1.appendPropertyInAstObject(recorder, pathsAstNode, projectKey, pathToProject[projectKey], 4);
                schematics_utilities_1.appendPropertyInAstObject(recorder, pathsAstNode, projectEnvKey, pathToProject[projectEnvKey], 4);
            }
            tree.commitUpdate(recorder);
            return tree;
        }
        catch (e) {
            console.error(e);
            throw new Error(`Could not update ${tsConfigPath}`);
        }
    };
}
//# sourceMappingURL=index.js.map